@@ -5,16 +5,40 @@
 use strict;
 use warnings;
 
-# POE System
+use Getopt::Long::Descriptive;
 use POE qw(
 	Wheel::ReadWrite
 	Component::Server::eris
 );
 
+#--------------------------------------------------------------------------#
+# Process Arguments
+my ($opt,$usage) = describe_options( '%c - %o',
+    ['eris-listen|el:s', "Address to listen for eris clients, default: 127.0.0.1", { default => '127.0.0.1' } ],
+    ['eris-port|ep:i',   "TCP port to listen for incoming syslog, default 9514", { default => 9514 } ],
+    [],
+    ['graphite-host|g:s',  "Host to use to submit graphite metrics, default: disabled" ],
+    ['graphite-port|gp:i', "Port for graphite metric submission, default: 2003", {default => 2003} ],
+    ['graphite-prefix:s',  "Graphite prefix for metrics, default from POE::Component::Server::eris"],
+    [],
+    ['help',       "Show this message and exit.", { shortcircuit => 1 } ],
+);
+
+if( $opt->help ) {
+    print $usage->text;
+    exit 0;
+}
+
+#--------------------------------------------------------------------------#
+# POE Session Initialization
+#
 # TCP Session Master
 POE::Component::Server::eris->spawn(
-		ListenAddress	=> '127.0.0.1',
-		ListenPort		=> 9514,
+		ListenAddress	=> $opt->eris_listen,
+		ListenPort		=> $opt->eris_port,
+        GraphitePort    => $opt->graphite_port,
+        $opt->graphite_host ? ( GraphiteHost => $opt->graphite_host ) : (),
+        $opt->graphite_prefix ? ( GraphitePrefix => $opt->graphite_prefix ) : (),
 );
 
 # Syslog-ng Stream Master
@@ -89,7 +113,7 @@ eris-dispatcher-stdin.pl - Example Implementation for using with STDIN
 
 =head1 VERSION
 
-version 2.0
+version 2.1
 
 =head1 AUTHOR
 
